import { Component, ViewEncapsulation, ChangeDetectionStrategy, Input, Injectable, ɵɵdefineInjectable, ɵɵinject, Pipe, NgModule } from '@angular/core';
import { assign, isString, reduce, get, omit, pick, size } from 'lodash-es';
import { HttpClient, HttpClientModule } from '@angular/common/http';
import { BehaviorSubject, of } from 'rxjs';
import { map, distinctUntilChanged, catchError, finalize } from 'rxjs/operators';
import { CommonModule } from '@angular/common';
import { DomSanitizer } from '@angular/platform-browser';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/styles-loader-raw/styles-loader-raw.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StylesLoaderRawComponent {
    constructor() {
        this.items = [];
        this._ = { assign, isString, reduce };
        this.trackByValue = (/**
         * @param {?} index
         * @param {?} value
         * @return {?}
         */
        (index, value) => value);
    }
    /**
     * @return {?}
     */
    get Items() {
        return this.items;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set Collection(value) {
        this.items = Object.values(this._.reduce(value, (/**
         * @param {?} items
         * @param {?} url
         * @return {?}
         */
        (items, url) => (!!url && this._.isString(url) && this._.assign(items, { [url]: url })) || items), {}));
    }
}
StylesLoaderRawComponent.decorators = [
    { type: Component, args: [{
                selector: 'styles-loader-raw',
                template: `
    <ng-container *ngIf="!!Items?.length">
      <ng-container *ngFor="let value of Items; trackBy: trackByValue">
        <ng-container *ngIf="!!value">
          <link async rel="stylesheet" [attr.data-url]="value" [href]="value | safeUrl" />
        </ng-container>
      </ng-container>
    </ng-container>
  `,
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
StylesLoaderRawComponent.propDecorators = {
    Collection: [{ type: Input }]
};
if (false) {
    /**
     * @type {?}
     * @private
     */
    StylesLoaderRawComponent.prototype.items;
    /** @type {?} */
    StylesLoaderRawComponent.prototype._;
    /** @type {?} */
    StylesLoaderRawComponent.prototype.trackByValue;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/enums/style-handling-mode.enum.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const StyleHandlingMode = {
    PassThrough: "PassThrough",
    VerifiedPassThrough: "VerifiedPassThrough",
    Literal: "Literal",
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/styles-loader.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StylesLoaderService {
    /**
     * @param {?} http
     */
    constructor(http) {
        this.http = http;
        this.loadingStylesSubscription = new BehaviorSubject({});
        this.loadingStyles$ = this.loadingStylesSubscription.asObservable();
        this._ = { assign, get, isString, omit, pick, size };
        this.isStyleLoading = (/**
         * @param {?} url
         * @return {?}
         */
        (url) => !!this._.get(this.loadingStylesSubscription.getValue(), url));
        this.isStyleLoading$ = (/**
         * @param {?} url
         * @return {?}
         */
        (url) => this.loadingStyles$.pipe(map((/**
         * @param {?} x
         * @return {?}
         */
        x => !!this._.get(x, url))), distinctUntilChanged()));
        this.areStylesLoading = (/**
         * @param {?} urls
         * @return {?}
         */
        (urls) => !!this._.size(this._.pick(this.loadingStylesSubscription.getValue(), urls)));
        this.areStylesLoading$ = (/**
         * @param {?} urls
         * @return {?}
         */
        (urls) => this.loadingStyles$.pipe(map((/**
         * @param {?} x
         * @return {?}
         */
        x => !!this._.size(this._.pick(x, urls)))), distinctUntilChanged()));
        this.removeFromLoading = (/**
         * @param {?} url
         * @return {?}
         */
        (url) => this.loadingStylesSubscription.next(this._.omit(this.loadingStylesSubscription.getValue(), url)));
        this.getStyle$ = (/**
         * @param {?} url
         * @param {?=} styleHandlingMode
         * @return {?}
         */
        (url, styleHandlingMode) => {
            if (!(!!url && this._.isString(url)) || this.isStyleLoading(url)) {
                return of(null);
            }
            /** @type {?} */
            const shm = this._.get(StyleHandlingMode, styleHandlingMode, StyleHandlingMode.VerifiedPassThrough);
            if (shm === StyleHandlingMode.PassThrough) {
                return of(url);
            }
            this.loadingStylesSubscription.next(this._.assign({}, this.loadingStylesSubscription.getValue(), { [url]: url }));
            /** @type {?} */
            const request = this.http.get(url, { responseType: 'blob' });
            return (shm === StyleHandlingMode.Literal //
                ? request.pipe(map((/**
                 * @param {?} result
                 * @return {?}
                 */
                result => URL.createObjectURL(result))))
                : request.pipe(map((/**
                 * @return {?}
                 */
                () => url)))).pipe(catchError((/**
             * @param {?} error
             * @return {?}
             */
            error => {
                console.error(error);
                return of(null);
            })), finalize((/**
             * @return {?}
             */
            () => this.removeFromLoading(url))));
        });
    }
}
StylesLoaderService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
StylesLoaderService.ctorParameters = () => [
    { type: HttpClient }
];
/** @nocollapse */ StylesLoaderService.ngInjectableDef = ɵɵdefineInjectable({ factory: function StylesLoaderService_Factory() { return new StylesLoaderService(ɵɵinject(HttpClient)); }, token: StylesLoaderService, providedIn: "root" });
if (false) {
    /**
     * @type {?}
     * @private
     */
    StylesLoaderService.prototype.loadingStylesSubscription;
    /** @type {?} */
    StylesLoaderService.prototype.loadingStyles$;
    /** @type {?} */
    StylesLoaderService.prototype._;
    /** @type {?} */
    StylesLoaderService.prototype.isStyleLoading;
    /** @type {?} */
    StylesLoaderService.prototype.isStyleLoading$;
    /** @type {?} */
    StylesLoaderService.prototype.areStylesLoading;
    /** @type {?} */
    StylesLoaderService.prototype.areStylesLoading$;
    /**
     * @type {?}
     * @private
     */
    StylesLoaderService.prototype.removeFromLoading;
    /** @type {?} */
    StylesLoaderService.prototype.getStyle$;
    /**
     * @type {?}
     * @private
     */
    StylesLoaderService.prototype.http;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/styles-loader/styles-loader.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StylesLoaderComponent {
    /**
     * @param {?} loaderService
     */
    constructor(loaderService) {
        this.loaderService = loaderService;
        this.items = [];
        this._ = { assign, reduce, isString, pick, get };
        this.trackByKey = (/**
         * @param {?} index
         * @param {?} __1
         * @return {?}
         */
        (index, { key = `${index}` }) => key);
    }
    /**
     * @return {?}
     */
    get Items() {
        return this.items;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set Config(value) {
        const { collection, handling } = this._.pick(value, ['collection', 'handling']);
        this.items = Object.values(this._.reduce(collection, (/**
         * @param {?} items
         * @param {?} url
         * @return {?}
         */
        (items, url) => (!!url &&
            this._.isString(url) &&
            this._.assign(items, {
                [url]: {
                    key: url,
                    url,
                    $: this.loaderService.getStyle$(url, this._.get(handling, url))
                }
            })) ||
            items), {}));
    }
}
StylesLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'styles-loader',
                template: `
    <ng-container *ngIf="!!Items?.length">
      <ng-container *ngFor="let obj of Items; trackBy: trackByKey">
        <ng-container *ngIf="obj.$ | async as style">
          <link async rel="stylesheet" [attr.data-url]="obj.url" [href]="style | safeUrl" />
        </ng-container>
      </ng-container>
    </ng-container>
  `,
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
StylesLoaderComponent.ctorParameters = () => [
    { type: StylesLoaderService }
];
StylesLoaderComponent.propDecorators = {
    Config: [{ type: Input }]
};
if (false) {
    /**
     * @type {?}
     * @private
     */
    StylesLoaderComponent.prototype.items;
    /** @type {?} */
    StylesLoaderComponent.prototype._;
    /** @type {?} */
    StylesLoaderComponent.prototype.trackByKey;
    /**
     * @type {?}
     * @private
     */
    StylesLoaderComponent.prototype.loaderService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/interfaces/styles-loader-config.interface.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function StylesLoaderConfig() { }
if (false) {
    /** @type {?} */
    StylesLoaderConfig.prototype.collection;
    /** @type {?|undefined} */
    StylesLoaderConfig.prototype.handling;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/pipes/safe-url/safe-url.pipe.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SafeUrlPipe {
    /**
     * @param {?} sanitizer
     */
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
        this.transform = (/**
         * @param {?} value
         * @return {?}
         */
        (value) => this.sanitizer.bypassSecurityTrustResourceUrl(value));
    }
}
SafeUrlPipe.decorators = [
    { type: Pipe, args: [{
                name: 'safeUrl'
            },] }
];
/** @nocollapse */
SafeUrlPipe.ctorParameters = () => [
    { type: DomSanitizer }
];
if (false) {
    /** @type {?} */
    SafeUrlPipe.prototype.transform;
    /**
     * @type {?}
     * @private
     */
    SafeUrlPipe.prototype.sanitizer;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-fi-styles-loader.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const components = [StylesLoaderComponent, StylesLoaderRawComponent];
class NgxFiStylesLoaderModule {
}
NgxFiStylesLoaderModule.decorators = [
    { type: NgModule, args: [{
                declarations: [...components, SafeUrlPipe],
                entryComponents: components,
                exports: components,
                imports: [CommonModule, HttpClientModule],
                providers: [StylesLoaderService]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ngx-fi-styles-loader.testing-module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StylesLoaderMockComponent {
    constructor() {
        this.Items = [];
    }
}
StylesLoaderMockComponent.decorators = [
    { type: Component, args: [{
                selector: 'styles-loader',
                template: 'styles-loader'
            }] }
];
StylesLoaderMockComponent.propDecorators = {
    Config: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    StylesLoaderMockComponent.prototype.Items;
    /** @type {?} */
    StylesLoaderMockComponent.prototype.Config;
}
class StylesLoaderRawMockComponent {
}
StylesLoaderRawMockComponent.decorators = [
    { type: Component, args: [{
                selector: 'styles-loader-raw',
                template: 'styles-loader-raw'
            }] }
];
StylesLoaderRawMockComponent.propDecorators = {
    Collection: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    StylesLoaderRawMockComponent.prototype.Items;
    /** @type {?} */
    StylesLoaderRawMockComponent.prototype.Collection;
}
class StylesLoaderMockService {
    constructor() {
        this.loadingStyles$ = new BehaviorSubject({});
        this.isStyleLoading = (/**
         * @param {?} url
         * @return {?}
         */
        (url) => false);
        this.isStyleLoading$ = (/**
         * @param {?} url
         * @return {?}
         */
        (url) => of(false));
        this.areStylesLoading = (/**
         * @param {?} urls
         * @return {?}
         */
        (urls) => false);
        this.areStylesLoading$ = (/**
         * @param {?} urls
         * @return {?}
         */
        (urls) => of(false));
        this.getStyle$ = (/**
         * @param {?} url
         * @param {?=} styleHandlingMode
         * @return {?}
         */
        (url, styleHandlingMode) => of(null));
    }
}
if (false) {
    /** @type {?} */
    StylesLoaderMockService.prototype.loadingStyles$;
    /** @type {?} */
    StylesLoaderMockService.prototype.isStyleLoading;
    /** @type {?} */
    StylesLoaderMockService.prototype.isStyleLoading$;
    /** @type {?} */
    StylesLoaderMockService.prototype.areStylesLoading;
    /** @type {?} */
    StylesLoaderMockService.prototype.areStylesLoading$;
    /** @type {?} */
    StylesLoaderMockService.prototype.getStyle$;
}
/** @type {?} */
const components$1 = [StylesLoaderMockComponent, StylesLoaderRawMockComponent];
class NgxFiStylesLoaderTestingModule {
}
NgxFiStylesLoaderTestingModule.decorators = [
    { type: NgModule, args: [{
                declarations: components$1,
                entryComponents: components$1,
                exports: [...components$1],
                providers: [
                    {
                        provide: StylesLoaderService,
                        useClass: StylesLoaderMockService
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-fi-styles-loader.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxFiStylesLoaderModule, NgxFiStylesLoaderTestingModule, StyleHandlingMode, StylesLoaderComponent, StylesLoaderMockComponent, StylesLoaderMockService, StylesLoaderRawComponent, StylesLoaderRawMockComponent, StylesLoaderService, SafeUrlPipe as ɵa };
//# sourceMappingURL=ngx-fi-styles-loader.js.map
