import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { StyleHandlingMode } from '../enums/style-handling-mode.enum';
import { IStylesLoaderService } from '../interfaces/istyles-loader-service.interface';
export declare class StylesLoaderService implements IStylesLoaderService {
    private http;
    private readonly loadingStylesSubscription;
    readonly loadingStyles$: Observable<{
        [key: string]: string;
    }>;
    readonly _: {
        assign: {
            <TObject, TSource>(object: TObject, source: TSource): TObject & TSource;
            <TObject, TSource1, TSource2>(object: TObject, source1: TSource1, source2: TSource2): TObject & TSource1 & TSource2;
            <TObject, TSource1, TSource2, TSource3>(object: TObject, source1: TSource1, source2: TSource2, source3: TSource3): TObject & TSource1 & TSource2 & TSource3;
            <TObject, TSource1, TSource2, TSource3, TSource4>(object: TObject, source1: TSource1, source2: TSource2, source3: TSource3, source4: TSource4): TObject & TSource1 & TSource2 & TSource3 & TSource4;
            <TObject>(object: TObject): TObject;
            (object: any, ...otherArgs: any[]): any;
        };
        get: {
            <TObject extends object, TKey extends keyof TObject>(object: TObject, path: TKey | [TKey]): TObject[TKey];
            <TObject extends object, TKey extends keyof TObject>(object: TObject, path: TKey | [TKey]): TObject[TKey];
            <TObject extends object, TKey extends keyof TObject, TDefault>(object: TObject, path: TKey | [TKey], defaultValue: TDefault): TDefault | Exclude<TObject[TKey], undefined>;
            <TObject extends object, TKey1 extends keyof TObject, TKey2 extends keyof TObject[TKey1]>(object: TObject, path: [TKey1, TKey2]): TObject[TKey1][TKey2];
            <TObject extends object, TKey1 extends keyof TObject, TKey2 extends keyof TObject[TKey1]>(object: TObject, path: [TKey1, TKey2]): TObject[TKey1][TKey2];
            <TObject extends object, TKey1 extends keyof TObject, TKey2 extends keyof TObject[TKey1], TDefault>(object: TObject, path: [TKey1, TKey2], defaultValue: TDefault): TDefault | Exclude<TObject[TKey1][TKey2], undefined>;
            <TObject extends object, TKey1 extends keyof TObject, TKey2 extends keyof TObject[TKey1], TKey3 extends keyof TObject[TKey1][TKey2]>(object: TObject, path: [TKey1, TKey2, TKey3]): TObject[TKey1][TKey2][TKey3];
            <TObject extends object, TKey1 extends keyof TObject, TKey2 extends keyof TObject[TKey1], TKey3 extends keyof TObject[TKey1][TKey2]>(object: TObject, path: [TKey1, TKey2, TKey3]): TObject[TKey1][TKey2][TKey3];
            <TObject extends object, TKey1 extends keyof TObject, TKey2 extends keyof TObject[TKey1], TKey3 extends keyof TObject[TKey1][TKey2], TDefault>(object: TObject, path: [TKey1, TKey2, TKey3], defaultValue: TDefault): TDefault | Exclude<TObject[TKey1][TKey2][TKey3], undefined>;
            <TObject extends object, TKey1 extends keyof TObject, TKey2 extends keyof TObject[TKey1], TKey3 extends keyof TObject[TKey1][TKey2], TKey4 extends keyof TObject[TKey1][TKey2][TKey3]>(object: TObject, path: [TKey1, TKey2, TKey3, TKey4]): TObject[TKey1][TKey2][TKey3][TKey4];
            <TObject extends object, TKey1 extends keyof TObject, TKey2 extends keyof TObject[TKey1], TKey3 extends keyof TObject[TKey1][TKey2], TKey4 extends keyof TObject[TKey1][TKey2][TKey3]>(object: TObject, path: [TKey1, TKey2, TKey3, TKey4]): TObject[TKey1][TKey2][TKey3][TKey4];
            <TObject extends object, TKey1 extends keyof TObject, TKey2 extends keyof TObject[TKey1], TKey3 extends keyof TObject[TKey1][TKey2], TKey4 extends keyof TObject[TKey1][TKey2][TKey3], TDefault>(object: TObject, path: [TKey1, TKey2, TKey3, TKey4], defaultValue: TDefault): TDefault | Exclude<TObject[TKey1][TKey2][TKey3][TKey4], undefined>;
            <T>(object: import("lodash").NumericDictionary<T>, path: number): T;
            <T>(object: import("lodash").NumericDictionary<T>, path: number): T;
            <T, TDefault>(object: import("lodash").NumericDictionary<T>, path: number, defaultValue: TDefault): T | TDefault;
            <TDefault>(object: null, path: import("lodash").Many<string | number | symbol>, defaultValue: TDefault): TDefault;
            (object: null, path: import("lodash").Many<string | number | symbol>): undefined;
            (object: any, path: import("lodash").Many<string | number | symbol>, defaultValue?: any): any;
        };
        isString: (value?: any) => value is string;
        omit: {
            <T extends object, K extends (string | number | symbol)[]>(object: T, ...paths: K): Pick<T, Exclude<keyof T, K[number]>>;
            <T extends object, K extends keyof T>(object: T, ...paths: import("lodash").Many<K>[]): Pick<T, Exclude<keyof T, K>>;
            <T extends object>(object: T, ...paths: import("lodash").Many<string | number | symbol>[]): Partial<T>;
        };
        pick: {
            <T extends object, U extends keyof T>(object: T, ...props: import("lodash").Many<U>[]): Pick<T, U>;
            <T>(object: T, ...props: import("lodash").Many<string | number | symbol>[]): Partial<T>;
        };
        size: (collection: string | object) => number;
    };
    constructor(http: HttpClient);
    isStyleLoading: (url: string) => boolean;
    isStyleLoading$: (url: string) => Observable<boolean>;
    areStylesLoading: (urls: string[]) => boolean;
    areStylesLoading$: (urls: string[]) => Observable<boolean>;
    private removeFromLoading;
    getStyle$: (url: string, styleHandlingMode?: StyleHandlingMode) => Observable<string>;
}
